@@ -140,6 +140,12 @@ Special Properties
 .. autoclass:: Include
 .. autoclass:: Override
 
+Validation-only Properties
+--------------------------
+
+.. autoclass:: PandasDataFrame
+.. autoclass:: PandasGroupBy
+
 Validation Control
 ------------------
 
@@ -203,6 +209,8 @@ __all__ = (
     'Float',
     'FontSize',
     'FontSizeSpec',
+    'HatchPatternSpec',
+    'HatchPatternType',
     'Image',
     'Include',
     'Instance',
@@ -215,6 +223,8 @@ __all__ = (
     'MinMaxBounds',
     'NumberSpec',
     'Override',
+    'PandasDataFrame',
+    'PandasGroupBy',
     'Percent',
     'RGB',
     'Regex',
@@ -264,6 +274,7 @@ from .property.dataspec import DistanceSpec; DistanceSpec
 from .property.dataspec import expr; expr
 from .property.dataspec import field; field
 from .property.dataspec import FontSizeSpec; FontSizeSpec
+from .property.dataspec import HatchPatternSpec; HatchPatternSpec
 from .property.dataspec import MarkerSpec; MarkerSpec
 from .property.dataspec import NumberSpec; NumberSpec
 from .property.dataspec import ScreenDistanceSpec; ScreenDistanceSpec
@@ -294,6 +305,9 @@ from .property.numeric import Size; Size
 
 from .property.override import Override ; Override
 
+from .property.pandas import PandasDataFrame ; PandasDataFrame
+from .property.pandas import PandasGroupBy ; PandasGroupBy
+
 from .property.primitive import Bool; Bool
 from .property.primitive import Complex; Complex
 from .property.primitive import Int; Int
@@ -306,6 +320,7 @@ from .property.struct import Struct; Struct
 
 from .property.visual import DashPattern; DashPattern
 from .property.visual import FontSize; FontSize
+from .property.visual import HatchPatternType; HatchPatternType
 from .property.visual import Image; Image
 from .property.visual import MinMaxBounds; MinMaxBounds
 from .property.visual import MarkerType; MarkerType
