@@ -60,6 +60,8 @@ ALL = (
     'Float',
     'FontSize',
     'FontSizeSpec',
+    'HatchPatternSpec',
+    'HatchPatternType',
     'Image',
     'Include',
     'Instance',
@@ -72,6 +74,8 @@ ALL = (
     'MinMaxBounds',
     'NumberSpec',
     'Override',
+    'PandasDataFrame',
+    'PandasGroupBy',
     'Percent',
     'RGB',
     'Regex',
