@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -27,7 +26,7 @@ log = logging.getLogger(__name__)
 
 # Bokeh imports
 from ...core.has_props import abstract
-from ...core.properties import Date, Either, Float, Instance, Int, List, String, Tuple, Dict
+from ...core.properties import Date, Either, Float, Instance, Int, List, String, Tuple, Dict, ColorHex
 
 from ..callbacks import Callback
 
@@ -39,11 +38,14 @@ from .widget import Widget
 
 __all__ = (
     'AutocompleteInput',
+    'ColorPicker',
     'DatePicker',
+    'FileInput',
     'InputWidget',
     'MultiSelect',
     'PasswordInput',
     'Select',
+    'Spinner',
     'TextInput',
     'TextAreaInput'
 )
@@ -52,6 +54,7 @@ __all__ = (
 # Dev API
 #-----------------------------------------------------------------------------
 
+
 @abstract
 class InputWidget(Widget):
     ''' Abstract base class for input widgets.
@@ -78,6 +81,48 @@ class InputWidget(Widget):
 # General API
 #-----------------------------------------------------------------------------
 
+class FileInput(Widget):
+    ''' Present a file-chooser dialog to users and return the contents of a
+    selected file.
+
+    '''
+
+    value = String(default="", readonly=True, help="""
+    A base64-encoded string of the contents of the selected file.
+    """)
+
+    mime_type = String(default="", readonly=True, help="""
+    The mime type of the selected file.
+    """)
+
+    filename = String(default="", readonly=True, help="""
+    The filename of the selected file.
+    The file path is not included as browsers do not allow access to it.
+    """)
+
+    accept = String(default="", help="""
+    Comma-separated list of standard HTML file input filters that restrict what
+    files the user can pick from. Values can be:
+
+    `<file extension>`:
+        Specific file extension(s) (e.g: .gif, .jpg, .png, .doc) are pickable
+
+    `audio/*`:
+        all sound files are pickable
+
+    `video/*`:
+        all video files are pickable
+
+    `image/*`:
+        all image files are pickable
+
+    `<media type>`:
+        A valid `IANA Media Type`_, with no parameters.
+
+    .. _IANA Media Type: https://www.iana.org/assignments/media-types/media-types.xhtml
+    """)
+
+
 class TextInput(InputWidget):
     ''' Single-line input widget.
 
@@ -87,14 +132,20 @@ class TextInput(InputWidget):
     Initial or entered text value.
     """)
 
+    value_input = String(default="", help="""
+    Initial or entered text value that triggers a callback whenever the value changes.
+    """)
+
     callback = Instance(Callback, help="""
     A callback to run in the browser whenever the user unfocuses the
     ``TextInput`` widget by hitting Enter or clicking outside of the text box
     area.
+
+    DEPRECATED: use .js_on_change or .on_change with "value" or "value_input"
     """)
 
     placeholder = String(default="", help="""
-    Placeholder for empty input field
+    Placeholder for empty input field.
     """)
 
 
@@ -142,8 +193,8 @@ class Select(InputWidget):
     ''' Single-select widget.
 
     '''
-    options = Either( List(Either(String, Tuple(Either(Int,String), String))),
-        Dict(String, List(Either(String, Tuple(Either(Int,String), String)))), help="""
+    options = Either(List(Either(String, Tuple(Either(Int, String), String))),
+        Dict(String, List(Either(String, Tuple(Either(Int, String), String)))), help="""
     Available selection options. Options may be provided either as a list of
     possible string values, or as a list of tuples, each of the form
     ``(value, label)``. In the latter case, the visible widget text for each
@@ -161,6 +212,7 @@ class Select(InputWidget):
     value changes.
     """)
 
+
 class MultiSelect(InputWidget):
     ''' Multi-select widget.
 
@@ -188,6 +240,7 @@ class MultiSelect(InputWidget):
     show less than 3 options.)
     """)
 
+
 class DatePicker(InputWidget):
     ''' Calendar-based date picker widget.
 
@@ -209,6 +262,52 @@ class DatePicker(InputWidget):
     A callback to run in the browser whenever the current date value changes.
     """)
 
+
+class ColorPicker(InputWidget):
+    ''' Color picker widget
+
+    .. warning::
+        This widget as a limited support on *Internet Explorer* (it will be displayed
+        as a simple text input).
+
+    '''
+
+    color = ColorHex(default='#000000', help="""
+    The initial color of the picked color (named or hexadecimal)
+    """)
+
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever the current date value changes.
+    """)
+
+
+class Spinner(InputWidget):
+    ''' Spinner widget for numerical inputs
+
+    '''
+
+    value = Float(default=0, help="""
+    The initial value of the spinner
+    """)
+
+    step = Float(default=1, help="""
+    The step added or subtracted to the current value
+    """)
+
+    low = Float(help="""
+    Optional lowest allowable value.
+    """)
+
+    high = Float(help="""
+    Optional highest allowable value.
+    """)
+
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever the user unfocuses the
+    ``SpinBox`` widget by hitting Enter or clicking outside of the box
+    area.
+    """)
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
